# Change Log

The format is based on [Keep a Changelog](http://keepachangelog.com/).

## [Unreleased]
### Added
- ...

### Changed
- ...

## [0.2.2] - 2017-01-29
### Added
- [workstation] enable canonical partner repositories
- [workstation] create ~/.gnupg directory
- [workstation] purge unity conflict packages before installing kubuntu-full
- [workstation] gitconfig setup
- [workstation] netrc setup

### Changed
- [workstation] role tasks modularised

## [0.2.1] - 2017-01-26
### Changed
- [infra] bugfix install rule trying to install roles dir

## [0.2.0] - 2017-01-26
### Added
- [bootstrap] user groups
- [bootstrap] ansible/snorriheim ppas
- [ros] generic ros install/update
- [workstation] lots of ppa's and debs
- [update] updates itself and ansible

## [0.1.0] - 2017-01-26
### Added
- [infra] skeleton structure

[Unreleased]: https://github.com/stonier/groot_ansible/compare/0.2.1...HEAD
[0.2.1]: https://github.com/stonier/groot_ansible/compare/0.2.0...0.2.1
[0.2.0]: https://github.com/stonier/groot_ansible/compare/0.1.0...0.2.0
[0.1.0]: https://github.com/stonier/groot_ansible/compare/d85f7d176f25cf9bec221bd309cd3e4c942891ad...0.1.0
